import './DefaultStyle.css';
import './App.css';
import imageSrc from './img/1.png';
import imageWork1 from './img/2.jpg';
import imageWork2 from './img/3.jpg';
import imageWork3 from './img/4.jpg';
import socialLink1 from './img/facebook.svg';
import socialLink2 from './img/instagram.svg';
import socialLink3 from './img/twitter.svg';
import socialLink4 from './img/linledin.svg';


//header
const Header = (props) => {
    return (
        <header class='container'>
            <nav>
                <ul>
                    {props.headerLink.map((post) =>
                        <li>
                            <a href={post.url}>
                                {post.content}
                            </a>
                        </li>
                    )}
                </ul>
            </nav>
        </header>
    );
}
const headerLink = [
    {id: 1, content: 'Works', url: '#'},
    {id: 2, content: 'Blog', url: '#'},
    {id: 3, content: 'Contact', url: '#'}
];

//about
const About = ({title='title', description='description', link='#', linkText='link text', img}) =>
    <div className='about'>
    <div className="container">
        <div className="about__row">
            <div className="about__content">
                <h1 >{title}</h1>
                <p>{description}</p>
                <a href={link}>{linkText}</a>
            </div>
            <div className="about__avatar">
                <img src={img} alt="img"/>
            </div>
        </div>
    </div>
</div>

//posts
const TitleBlock = ({name='title', url="#", urlText}) =>
    <div className="container">
        <div className='posts-title'>
            <p>{name}</p>
            <a href={url}>{urlText}</a>
        </div>
    </div>
const Posts = (posts) =>{
    return (
        <div className="posts">
            <div className="container">
                <div className="posts-body">
                        {posts.posts.map((post) =>
                            <div className="block-posts">
                                <div className="block-posts__content">
                                    <a href={post.urlTitle} className="block-posts__title">{post.title}</a>
                                    <div className="block-posts__description">
                                        <div className="block-posts__data">{post.date}</div>
                                        <a href={post.urlPrograms} className="block-posts__programs">{post.programs}</a>
                                    </div>
                                    <div className="block-posts__text">{post.text}</div>
                                </div>
                            </div>
                        )}
                </div>
            </div>
        </div>
    );
}
const posts = [
    {id: 1, title: 'Making a design system from scratch', urlTitle: '#', date: '12 Feb 2020', programs: 'Design, Pattern', urlPrograms:'#', text: 'Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velit mollit. Exercitation veniam consequat sunt nostrud amet.'},
    {id: 2, title: 'Creating pixel perfect icons in Figma', urlTitle: '#', date: '20 Jul 2020', programs: 'Figma, Icon Design', urlPrograms:'#', text: 'Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velit mollit. Exercitation veniam consequat sunt nostrud amet.'}
];

//works
const WorkPost = ({img, urlPost='#', title='title', date='data', program='', text='text'}) =>
    <div className="container">
            <div className="posts-works__body">
                <div className="posts-works__item works-block">
                    <a href={urlPost} className="works-block__img ibg">
                        <img src={img} alt="1"/>
                    </a>
                    <div className="works-block__content">
                        <a href={urlPost} className="works-block__title">{title}</a>
                        <div className="works-block__outside">
                            <div className="works-block__data">{date}</div>
                            <a href={urlPost} className="works-block__link">{program}</a>
                        </div>
                        <div className="works-block__text">{text}</div>
                    </div>
                </div>
            </div>
    </div>

//footer
const Footer = (footerLinks) => {
    return (
        <footer className="footer">
            <div className="container">
                <div className="footer__links">
                    {footerLinks.footerLinks.map((link) =>
                        <a href={link.url}>
                            <img src={link.img} alt="img"/>
                        </a>
                    )}
                </div>
                <div className="footer__copyright">Copyright ©2021 All rights reserved</div>
            </div>
        </footer>
    );
}
const footerLinks = [
    {id: 1, url: 'https://www.facebook.com/', img: socialLink1},
    {id: 2, url: 'https://www.instagram.com/', img: socialLink2},
    {id: 3, url: 'https://www.twitter.com/', img: socialLink3},
    {id: 4, url: 'https://www.linkedin.com/', img: socialLink4}
];

function App() {
  return (
    <div class='wrapper'>
      <main>
          <Header headerLink={headerLink} />
          <About title={'Hi, I am John, Creative Technologist'}
                 description={'Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velit mollit. Exercitation veniam consequat sunt nostrud amet.'}
                 linkBtn={'#'}
                 linkText={'Download Resume'}
                 img={imageSrc}/>
          <TitleBlock name={'Recent posts'}
                      url={'#'}
                      urlText={'View all'}/>
          <Posts posts={posts}/>
          <TitleBlock name={'Featured works'}
                      url={'#'}
                      urlText={''}/>
          <WorkPost img={imageWork1}
                    urlPost='#'
                    title='Designing Dashboards'
                    date='2020'
                    program='Dashboard'
                    text='Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velitmollit. Exercitation veniam consequat sunt nostrud amet.'/>
          <WorkPost img={imageWork2}
                    urlPost='#'
                    title='Vibrant Portraits of 2020'
                    date='2020'
                    program='Illustration'
                    text='Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velitmollit. Exercitation veniam consequat sunt nostrud amet.'/>
          <WorkPost img={imageWork3}
                    urlPost='#'
                    title='36 Days of Malayalam type'
                    date='2020'
                    program='Typography'
                    text='Amet minim mollit non deserunt ullamco est sit aliqua dolor do amet sint. Velit officia consequat duis enim velitmollit. Exercitation veniam consequat sunt nostrud amet.'/>
          <Footer footerLinks={footerLinks}/>
      </main>
    </div>
  );
}
export default App;